# OrzMC

A project for deploy minecraft client

Only support Python >=2.7, <4


# Support Minecraft Client Version

- 1.13

This Program has been uploaded into PyPI

# Usage

You should have a jre runtime on you device

```
$ pip install orzmc
$ mkdir minecraft
$ cd minecraft
$ orzmc
```

